# nnde
nnde is a package of Python modules which implement a set of neural networks
which solve ordinary and partial differential equations.

The technique is based on Lagaris et al (1998).

Reference: Lagaris et al, IEEE Transactions on Neural Networks 8(5),
p. 987 (1998).

# Contact

Eric Winter
ewinter@stsci.edu
2020-08-11
